disp(' ');
disp(' beam_rotating.m,  ver 1.8, January 15, 2014 ');
disp(' ');
disp(' by Tom Irvine ');
disp(' Email: tom@vibrationdata.com ');
disp(' ');
disp(' This script calculates the natural frequencies of a  ');
disp(' rotating beam (like a helicopter blade) via the finite ');
disp(' element method. ');
disp(' ');
disp(' Assume negligible hub radius. ');
disp(' ');
%
close all
clear all
%
pm=0.;
%
disp(' ');
disp(' Select units:  1=English 2=metric ');
iu=input(' ');
%
[E,I,A,rho,ibc,ne,total_length,xv,dx,dof,ipm,pm,xpm]=beam_data_entry(iu);
%
dof_orig=2*ne+2;
%
[klocal] = local_stiffness_rotating(E,I,ne,dx,rho,total_length);
[mlocal] = local_mass(rho,ne,dx);
%
[stiff,mass,dof,dof_status]=assembly(ne,klocal,mlocal,ibc,dof,ipm,pm,xpm,dx);
%
[fn,omega,ModeShapes,MST]=Generalized_Eigen(stiff,mass,2);
%
mode=ModeShapes;
%
v=ones(dof,1);
%
disp(' ');
disp('        Natural    Participation    Effective  ');
disp('Mode   Frequency      Factor        Modal Mass ');
%    
%  The accuracy decreases with mode number.
%
LM=mode'*mass*v;
pf=LM;
sum=0;
%    
mmm=mode'*mass*mode;   
%
pff=zeros(dof,1);
emm=zeros(dof,1);
%
for i=1:dof
    pff(i)=pf(i)/mmm(i,i);
    emm(i)=pf(i)^2/mmm(i,i);
    if(emm(i) < rho*total_length/100000.)
        emm(i)=0.;
        pff(i)=0.;
    end
    out1 = sprintf('%d  %10.4g Hz   %10.4g   %10.4g',i,fn(i),pff(i),emm(i) );
    disp(out1)
    sum=sum+emm(i);
end
%
disp(' ')
if(iu==1)
    out1 = sprintf(' Total Effective Modal Mass = %10.4g lbf sec^2/in',sum );
else
    out1 = sprintf(' Total Effective Modal Mass = %10.4g kg',sum );    
end    
disp(out1)
disp(' ')
%
if(iu==1)
    out1 = sprintf(' Total Mass = %10.4g lbf sec^2/in',(pm + rho*total_length) );
else
    out1 = sprintf(' Total Mass = %10.4g kg',(pm + rho*total_length) );    
end
disp(out1)
%
if(iu==1)
    out1 = sprintf('            = %10.4g lbm',(pm*386 + rho*total_length*386. ));
    disp(out1)
end
%
if(max(xv)>total_length)
    xv(length(xv))=[];
end
%
[pmode]=plot_modes(dof_status,mode,dof,xv,fn,iu);
%
clear sum;